@@ -4,10 +4,10 @@ from typing import Tuple
 import numpy as np
 import pandas as pd
 
-from handler.constants.constants import RESOLUTION, FUTURE_MONTH
-from handler.AWSdata import aws
-from handler.raster_handler.rasterhandler import RasterHandler
-from handler.printMessageHandler.formatePrint import Formatter
+from constants.constants import RESOLUTION, FUTURE_MONTH
+from AWSdata import aws
+from raster_handler.rasterhandler import RasterHandler
+from printMessageHandler.formatePrint import Formatter
 
 
 class Data_Handler():
